==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/StrategyBasedIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FinancialIndicatorDescriptionMetadata } from "./FinancialIndicatorDescriptionMetadata";
/**
 * @hidden
 */
export let StrategyBasedIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class StrategyBasedIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (StrategyBasedIndicatorDescriptionMetadata.a == null) {
                StrategyBasedIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                StrategyBasedIndicatorDescriptionMetadata.c(StrategyBasedIndicatorDescriptionMetadata.a);
            }
            if (a.k(StrategyBasedIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ab(StrategyBasedIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            FinancialIndicatorDescriptionMetadata.c(a);
        }
        static d(a) {
            StrategyBasedIndicatorDescriptionMetadata.b(a);
            a.ac("StrategyBasedIndicator", StrategyBasedIndicatorDescriptionMetadata.a);
        }
    }
    StrategyBasedIndicatorDescriptionMetadata.$t = markType(StrategyBasedIndicatorDescriptionMetadata, 'StrategyBasedIndicatorDescriptionMetadata');
    StrategyBasedIndicatorDescriptionMetadata.a = null;
    return StrategyBasedIndicatorDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/StrategyBasedIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FinancialIndicatorDescriptionMetadata } from "./FinancialIndicatorDescriptionMetadata";
/**
 * @hidden
 */
export let StrategyBasedIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class StrategyBasedIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (StrategyBasedIndicatorDescriptionMetadata.a == null) {
                StrategyBasedIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                StrategyBasedIndicatorDescriptionMetadata.c(StrategyBasedIndicatorDescriptionMetadata.a);
            }
            if (a.k(StrategyBasedIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ac(StrategyBasedIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            FinancialIndicatorDescriptionMetadata.c(a);
        }
        static d(a) {
            StrategyBasedIndicatorDescriptionMetadata.b(a);
            a.ad("StrategyBasedIndicator", StrategyBasedIndicatorDescriptionMetadata.a);
        }
    }
    StrategyBasedIndicatorDescriptionMetadata.$t = markType(StrategyBasedIndicatorDescriptionMetadata, 'StrategyBasedIndicatorDescriptionMetadata');
    StrategyBasedIndicatorDescriptionMetadata.a = null;
    return StrategyBasedIndicatorDescriptionMetadata;
})();
